@@ -1,7 +1,7 @@
 ## ------------------------------------------------------------------------
 library(satellite)
 path <- system.file("extdata", package = "satellite")
-files <- list.files(path, pattern = glob2rx("LC8*.tif"), full.names = TRUE)
+files <- list.files(path, pattern = glob2rx("LC08*.TIF"), full.names = TRUE)
 sat <- satellite(files)
 
 ## ------------------------------------------------------------------------
